@@ -16,7 +16,7 @@ do
 			;;
 		o)
 			outname=${OPTARG}
-			;;			
+			;;
                 *)
                         usage
                         exit 1
@@ -32,18 +32,20 @@ fi
 touch genometable.split
 sed '1d' $ref| awk -v OFS="\t" '{print $3,$5,$6,$2,$1,$4}' >ref.bed
 
+TAB="$(printf '\\\011')"
+
 for i in `cat $gt | cut -f 1`
 do
 	chromosome=$i
 	length=`awk '$1 == "'$chromosome'" {print $2}' $gt`
 	endlength=`expr $length + $res`
-	
+
 	seq 0 $res $length > start
 	seq $res $res $endlength > end
-	paste start end | sed "s/^/${chromosome}\t/g"  >> genometable.split
+	paste start end | sed "s/^/${chromosome}${TAB}/g"  >> genometable.split
 done
 
 bedtools coverage -a genometable.split -b ref.bed |cut -f 1-4 > ${outname}.txt
 
 
-rm start end ref.bed
+rm start end ref.bed genometable.split
